@@ -3,11 +3,11 @@
 # An example of using Python and XlsxWriter to write some "rich strings",
 # i.e., strings with multiple formats.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
-workbook = Workbook('rich_strings.xlsx')
+workbook = xlsxwriter.Workbook('rich_strings.xlsx')
 worksheet = workbook.add_worksheet()
 
 worksheet.set_column('A:A', 30)
