@@ -7,11 +7,11 @@
 #
 # See sparklines2.py for examples of more complex sparkline formatting.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
-workbook = Workbook('sparklines1.xlsx')
+workbook = xlsxwriter.Workbook('sparklines1.xlsx')
 worksheet = workbook.add_worksheet()
 
 # Some sample data to plot.
