@@ -6,12 +6,12 @@
 # This program is shown, with explanations, in Tutorial 1 of the XlsxWriter
 # documentation.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
 # Create a workbook and add a worksheet.
-workbook = Workbook('Expenses01.xlsx')
+workbook = xlsxwriter.Workbook('Expenses01.xlsx')
 worksheet = workbook.add_worksheet()
 
 # Some data we want to write to the worksheet.
